BaseTabular Class
=================

This is the base class for tabular data structures in PyNeon, such as
:class:`pyneon.Events` and :class:`pyneon.Stream`. It is not intended to be
used directly, but provides common functionality for its subclasses.

.. autoclass:: pyneon.tabular.BaseTabular
    :members:
    :show-inheritance: